@@ -12,12 +12,12 @@ from abc import ABC
 import torch
 import torch.nn as nn
 from torch.nn.modules.module import T
-from torchvision.models.utils import load_state_dict_from_url
 
 from zcls.config.key_word import KEY_OUTPUT
 from zcls.model.backbones.build import build_backbone
 from zcls.model.heads.build import build_head
 from zcls.model.norm_helper import freezing_bn
+from zcls.util.checkpoint import CheckPointer
 from zcls.util import logging
 
 logger = logging.get_logger(__name__)
@@ -42,14 +42,10 @@ class BaseRecognizer(nn.Module, ABC):
 
     def init_weights(self, pretrained, pretrained_num_classes, num_classes):
         if pretrained != "":
-            # local or remote links
-            if '://' in pretrained:
-                logger.info(f'load remote url: {pretrained}')
-                state_dict = load_state_dict_from_url(pretrained, progress=True)
-            else:
-                logger.info(f'load local url: {pretrained}')
-                state_dict = torch.load(pretrained, map_location=torch.device('cpu'))['model']
-            self.load_state_dict(state_dict=state_dict, strict=False)
+            logger.info(f'load pretrained: {pretrained}')
+            check_pointer = CheckPointer(model=self)
+            check_pointer.load(pretrained, map_location=torch.device('cpu'))
+            logger.info("finish loading model weights")
         if num_classes != pretrained_num_classes:
             fc = self.head.fc
             fc_features = fc.in_features
